Crate baseview

Crate baseview 

Re-exports

pub use dpi;

Modules

gl
host

Structs

Error
An error that can occur during window creation or manipulation.
HandlerError
An error that can be returned from a WindowHandler.
ParentWindowHandle
An owned handle to a parent window.
PlatformHandle
A lightweight handle to a window and its display connection.
Window
A handle to a Window created by baseview.
WindowContext
A handle to the window given to a WindowHandler, which it can then use to perform various operations on the window itself.
WindowSettings
Settings used when creating a new window.
WindowSize
A window’s size, which can be read in either logical or physical pixels.

Enums

DropData
DropEffect
Event
EventStatus
Return value for WindowHandler::on_event, indicating whether the event was handled by your window or should be passed back to the platform.
MouseButton
MouseCursor
MouseEvent
ScrollDelta
A scroll movement.
WindowEvent

Traits

WindowHandler

Functions

copy_to_clipboard