pub struct Error { /* private fields */ }Expand description
An error that can occur during window creation or manipulation.
This error type is opaque: you can only get error information from its Display implementation.
Which errors can occur on which operations can greatly vary between platforms. For instance on X11, the connection to the server can be lost, or the X server can send an invalid message, which is not possible on e.g. Windows or macOS.
This is the general Baseview error type.