pub struct HandlerError { /* private fields */ }Expand description
An error that can be returned from a WindowHandler.
This type does not implement the Error trait: instead it can be created from any kind of
Error type, using its From implementation and/or the ? operator.
Implementations
Sourceimpl HandlerError
impl HandlerError