Crate baseview

Crate baseview 

Re-exports

pub use dpi;

Modules

gl

Structs

PlatformHandle
A lightweight handle to a window and its display connection.
Window
WindowContext
A handle to the window given to a WindowHandler, which it can then use to perform various operations on the window itself.
WindowHandle
WindowOpenOptions
The options for opening a new window
WindowSize
A window’s size, which can be read in either logical or physical pixels.

Enums

DropData
DropEffect
Event
EventStatus
Return value for WindowHandler::on_event, indicating whether the event was handled by your window or should be passed back to the platform.
MouseButton
MouseCursor
MouseEvent
ScrollDelta
A scroll movement.
WindowEvent
WindowScalePolicy
The dpi scaling policy of the window

Traits

WindowHandler

Functions

copy_to_clipboard