Re-exports
pub use dpi;
Modules
Structs
- Platform
Handle - A lightweight handle to a window and its display connection.
- Window
- Window
Context - A handle to the window given to a
WindowHandler, which it can then use to perform various operations on the window itself. - Window
Handle - Window
Open Options - The options for opening a new window
- Window
Size - A window’s size, which can be read in either logical or physical pixels.
Enums
- Drop
Data - Drop
Effect - Event
- Event
Status - Return value for WindowHandler::on_event, indicating whether the event was handled by your window or should be passed back to the platform.
- Mouse
Button - Mouse
Cursor - Mouse
Event - Scroll
Delta - A scroll movement.
- Window
Event - Window
Scale Policy - The dpi scaling policy of the window