Crate baseview

Crate baseview 

Modules

gl

Structs

PhyPoint
A point in actual physical coordinates
PhySize
An actual size in physical coordinates
Point
A point in logical coordinates
Size
A size in logical coordinates
Window
WindowHandle
WindowInfo
The info about the window
WindowOpenOptions
The options for opening a new window

Enums

DropData
DropEffect
Event
EventStatus
Return value for WindowHandler::on_event, indicating whether the event was handled by your window or should be passed back to the platform.
MouseButton
MouseCursor
MouseEvent
ScrollDelta
A scroll movement.
WindowEvent
WindowScalePolicy
The dpi scaling policy of the window

Traits

WindowHandler

Functions

copy_to_clipboard