MouseEvent

Enum MouseEvent 

pub enum MouseEvent {
    CursorMoved {
        position: Point,
        modifiers: Modifiers,
    },
    ButtonPressed {
        button: MouseButton,
        modifiers: Modifiers,
    },
    ButtonReleased {
        button: MouseButton,
        modifiers: Modifiers,
    },
    WheelScrolled {
        delta: ScrollDelta,
        modifiers: Modifiers,
    },
    CursorEntered,
    CursorLeft,
    DragEntered {
        position: Point,
        modifiers: Modifiers,
        data: DropData,
    },
    DragMoved {
        position: Point,
        modifiers: Modifiers,
        data: DropData,
    },
    DragLeft,
    DragDropped {
        position: Point,
        modifiers: Modifiers,
        data: DropData,
    },
}

Variants



CursorMoved

The mouse cursor was moved

Fields

position: Point

The logical coordinates of the mouse position

modifiers: Modifiers

The modifiers that were held down just before the event.



ButtonPressed

A mouse button was pressed.

Fields

button: MouseButton

The button that was pressed.

modifiers: Modifiers

The modifiers that were held down just before the event.



ButtonReleased

A mouse button was released.

Fields

button: MouseButton

The button that was released.

modifiers: Modifiers

The modifiers that were held down just before the event.



WheelScrolled

The mouse wheel was scrolled.

Fields

delta: ScrollDelta

How much was scrolled, in factional lines.

modifiers: Modifiers

The modifiers that were held down just before the event.



CursorEntered

The mouse cursor entered the window.

May not be available on all platforms.



CursorLeft

The mouse cursor left the window.

May not be available on all platforms.



DragEntered

Fields

position: Point

The logical coordinates of the mouse position

modifiers: Modifiers

The modifiers that were held down just before the event.

data: DropData

Data being dragged



DragMoved

Fields

position: Point

The logical coordinates of the mouse position

modifiers: Modifiers

The modifiers that were held down just before the event.

data: DropData

Data being dragged



DragLeft



DragDropped

Fields

position: Point

The logical coordinates of the mouse position

modifiers: Modifiers

The modifiers that were held down just before the event.

data: DropData

Data being dragged