pub struct PlatformHandle { /* private fields */ }Expand description
A lightweight handle to a window and its display connection.
This type implements both HasWindowHandle and HasDisplayHandle, allowing users to access
the underlying platform window and display connection.
This type is cheaply cloneable. All cloned handles will always refer to the same window and display connection.
Unlike the WindowContext and WindowHandle types however, this handle can be safely sent,
used, and dropped across threads (it implements Send and Sync).
However, it is not guaranteed that this handle can be successfully used from other threads, depending on the platform.
Similarly, this handle is actually a weak handle: while it remains safe to use, its methods
will always return HandleError::Unavailable if called after the window it refers to has been
destroyed.
Platform compatibility notes
Depending on the platform, the PlatformHandle::window_handle method may return
HandleError::Unavailable if called from a thread other than the main thread (Even if the
window is still alive and well).